#ifndef WINPR_BUILD_FLAGS_H
#define WINPR_BUILD_FLAGS_H

#define WINPR_CFLAGS "-march=x86-64  -mtune=generic -O2 -pipe -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -fsigned-char -Wimplicit-function-declaration -Wno-jump-misses-init -fvisibility=hidden -O3 -DNDEBUG"
#define WINPR_COMPILER_ID "GNU"
#define WINPR_COMPILER_VERSION "15.2.1"
#define WINPR_TARGET_ARCH "x64"
#define WINPR_BUILD_CONFIG ""
#define WINPR_BUILD_TYPE "Release"

#endif /* WINPR_BUILD_FLAGS_H */
